Command line options
====================

Spyder's command line options are the following:

Options:
  -h, --help            show this help message and exit
  --new-instance        Run a new instance of Spyder, even if the single
                        instance mode has been turned on (default)
  --defaults            Reset configuration settings to defaults
  --reset               Remove all configuration files!
  --optimize            Optimize Spyder bytecode (this may require
                        administrative privileges)
  -w WORKING_DIRECTORY, --workdir=WORKING_DIRECTORY
                        Default working directory
  --hide-console        Hide parent console window (Windows)
  --show-console        (Deprecated) Does nothing, now the default behavior is to show the console
  --multithread         Internal console is executed in another thread
                        (separate from main application thread)
  --profile             Profile mode (internal test, not related with Python
                        profiling)
  --window-title=WINDOW_TITLE
                        String to show in the main window title
